@@ -2,11 +2,12 @@
 from typing import TYPE_CHECKING
 
 from perflint.for_loop_checker import ForLoopChecker, LoopInvariantChecker
+from perflint.list_checker import ListChecker
 
 if TYPE_CHECKING:
     from pylint.lint import PyLinter
 
-__version__ = "0.4.1"
+__version__ = "0.5.0"
 
 
 def register(linter: "PyLinter") -> None:
@@ -17,3 +18,4 @@ def register(linter: "PyLinter") -> None:
 
     linter.register_checker(ForLoopChecker(linter))
     linter.register_checker(LoopInvariantChecker(linter))
+    linter.register_checker(ListChecker(linter))
